/**
 * A single source of truth for all the classes used for decorations in Ixora.
 *  These are kept together here to simplify changing/adding classes later
 * and serve as a reference.
 *
 * Exports under this file don't need to follow any particular naming schema,
 * naming which can give an intuition on what the class is for is preferred.
 */
/** Classes for blockquote decorations. */
declare const blockquote: {
    /** Blockquote widget */
    widget: string;
    /** Replace decoration for the quote mark */
    mark: string;
};
declare const /** Classes for codeblock decorations. */
codeblock: {
    /** Codeblock widget */
    widget: string;
    /** First line of the codeblock widget */
    widgetBegin: string;
    /** Last line of the codeblock widget */
    widgetEnd: string;
};
declare const /** Classes for heading decorations. */
heading: {
    /** Heading decoration class */
    heading: string;
    /** Heading levels (h1, h2, etc) */
    level: (level: number) => string;
    /** Heading slug */
    slug: (slug: string) => string;
};
declare const /** Classes for link (URL) widgets. */
link: {
    /** URL widget */
    widget: string;
};
declare const /** Classes for list widgets. */
list: {
    /** List bullet */
    bullet: string;
    /** List task checkbox */
    taskCheckbox: string;
    /** Task list item with checkbox checked */
    taskChecked: string;
};

declare const classes_blockquote: typeof blockquote;
declare const classes_codeblock: typeof codeblock;
declare const classes_heading: typeof heading;
declare const classes_link: typeof link;
declare const classes_list: typeof list;
declare namespace classes {
  export {
    classes_blockquote as blockquote,
    classes_codeblock as codeblock,
    classes_heading as heading,
    classes_link as link,
    classes_list as list,
  };
}

export { codeblock as a, blockquote as b, classes as c, list as d, heading as h, link as l };
