var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
import {
  ViewPlugin,
  Decoration,
  EditorView
} from "@codemirror/view";
import {
  isCursorInRange,
  invisibleDecoration,
  iterateTreeInVisibleRanges,
  editorLines
} from "../util";
import { codeblock as classes } from "../classes";
const codeblock = () => [codeBlockPlugin, baseTheme];
const codeBlockPlugin = ViewPlugin.fromClass(class {
  constructor(view) {
    __publicField(this, "decorations");
    this.decorations = decorateCodeBlocks(view);
  }
  update(update) {
    if (update.docChanged || update.viewportChanged || update.selectionSet)
      this.decorations = decorateCodeBlocks(update.view);
  }
}, { decorations: (v) => v.decorations });
function decorateCodeBlocks(view) {
  const widgets = [];
  iterateTreeInVisibleRanges(view, {
    enter: ({ type, from, to, node }) => {
      if (!["FencedCode", "CodeBlock"].includes(type.name))
        return;
      editorLines(view, from, to).forEach((block, i) => {
        const lineDec = Decoration.line({
          class: [
            classes.widget,
            i === 0 ? classes.widgetBegin : block.to === to ? classes.widgetEnd : ""
          ].join(" ")
        });
        widgets.push(lineDec.range(block.from));
      });
      if (isCursorInRange(view, [from, to]))
        return;
      const codeBlock = node.toTree();
      codeBlock.iterate({
        enter: ({ type: type2, from: nodeFrom, to: nodeTo }) => {
          switch (type2.name) {
            case "CodeInfo":
            case "CodeMark":
              const decRange = invisibleDecoration.range(from + nodeFrom, from + nodeTo);
              widgets.push(decRange);
              break;
          }
        }
      });
    }
  });
  return Decoration.set(widgets, true);
}
const baseTheme = EditorView.baseTheme({
  ["." + classes.widget]: {
    backgroundColor: "#CCC7"
  },
  ["." + classes.widgetBegin]: {
    borderRadius: "5px 5px 0 0"
  },
  ["." + classes.widgetEnd]: {
    borderRadius: "0 0 5px 5px"
  }
});
export {
  codeblock
};
//# sourceMappingURL=code-block.js.map