var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
import {
  Decoration,
  EditorView,
  ViewPlugin
} from "@codemirror/view";
import { checkRangeOverlap, iterateTreeInVisibleRanges } from "../util";
import { headingSlugField } from "../state/heading-slug";
import { heading as classes } from "../classes";
const headings = () => [
  headingDecorationsPlugin,
  hideHeaderMarkPlugin,
  baseTheme
];
class HideHeaderMarkPlugin {
  constructor(view) {
    __publicField(this, "decorations");
    this.decorations = this.hideHeaderMark(view);
  }
  update(update) {
    if (update.docChanged || update.viewportChanged || update.selectionSet)
      this.decorations = this.hideHeaderMark(update.view);
  }
  hideHeaderMark(view) {
    const widgets = [];
    const ranges = view.state.selection.ranges;
    iterateTreeInVisibleRanges(view, {
      enter: ({ type, from, to }) => {
        const line = view.lineBlockAt(from);
        const cursorOverlaps = ranges.some(({ from: from2, to: to2 }) => checkRangeOverlap([from2, to2], [line.from, line.to]));
        if (cursorOverlaps)
          return;
        if (type.name === "HeaderMark" && /[#]/.test(view.state.sliceDoc(from, to))) {
          const dec = Decoration.replace({});
          widgets.push(dec.range(from, to + 1));
        }
      }
    });
    return Decoration.set(widgets, true);
  }
}
const hideHeaderMarkPlugin = ViewPlugin.fromClass(HideHeaderMarkPlugin, {
  decorations: (v) => v.decorations
});
class HeadingDecorationsPlugin {
  constructor(view) {
    __publicField(this, "decorations");
    this.decorations = this.decorateHeadings(view);
  }
  update(update) {
    if (update.docChanged || update.viewportChanged || update.selectionSet) {
      this.decorations = this.decorateHeadings(update.view);
    }
  }
  decorateHeadings(view) {
    const widgets = [];
    iterateTreeInVisibleRanges(view, {
      enter: ({ name, from }) => {
        var _a;
        if (!name.includes("Heading"))
          return;
        const slug = (_a = view.state.field(headingSlugField).find((s) => s.pos === from)) == null ? void 0 : _a.slug;
        const level = parseInt(/[1-6]$/.exec(name)[0]);
        const dec = Decoration.line({
          class: [
            classes.heading,
            classes.level(level),
            slug ? classes.slug(slug) : ""
          ].join(" ")
        });
        widgets.push(dec.range(view.state.doc.lineAt(from).from));
      }
    });
    return Decoration.set(widgets, true);
  }
}
const headingDecorationsPlugin = ViewPlugin.fromClass(HeadingDecorationsPlugin, { decorations: (v) => v.decorations });
const baseTheme = EditorView.baseTheme({
  ".cm-heading": {
    fontWeight: "bold"
  },
  ["." + classes.level(1)]: { fontSize: "2.2rem" },
  ["." + classes.level(2)]: { fontSize: "1.8rem" },
  ["." + classes.level(3)]: { fontSize: "1.4rem" },
  ["." + classes.level(4)]: { fontSize: "1.2rem" },
  ["." + classes.level(5)]: { fontSize: "1rem" },
  ["." + classes.level(6)]: { fontSize: "0.8rem" }
});
export {
  headings
};
//# sourceMappingURL=heading.js.map