var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
import { syntaxTree } from "@codemirror/language";
import {
  Decoration,
  EditorView,
  ViewPlugin,
  WidgetType
} from "@codemirror/view";
import { headingSlugField } from "../state/heading-slug";
import { checkRangeOverlap, invisibleDecoration } from "../util";
import { link as classes } from "../classes";
const links = () => [goToLinkPlugin, baseTheme];
class GoToLinkWidget extends WidgetType {
  constructor(link) {
    super();
    this.link = link;
  }
  toDOM(view) {
    const anchor = document.createElement("a");
    if (this.link.startsWith("#")) {
      const slugs = view.state.field(headingSlugField);
      anchor.addEventListener("click", () => {
        var _a;
        const pos = (_a = slugs.find((h) => h.slug === this.link.slice(1))) == null ? void 0 : _a.pos;
        if (typeof pos !== "undefined") {
          const tr = view.state.update({
            selection: { anchor: pos },
            scrollIntoView: true
          });
          view.dispatch(tr);
        }
      });
    } else
      anchor.href = this.link;
    anchor.target = "_blank";
    anchor.classList.add(classes.widget);
    anchor.textContent = "\u{1F517}";
    return anchor;
  }
}
function getLinkAnchor(view) {
  const widgets = [];
  for (const { from, to } of view.visibleRanges) {
    syntaxTree(view.state).iterate({
      from,
      to,
      enter: ({ type, from: from2, to: to2, node }) => {
        if (type.name !== "URL")
          return;
        const parent = node.parent;
        const blackListedParents = ["Image"];
        if (parent && !blackListedParents.includes(parent.name)) {
          const marks = parent.getChildren("LinkMark");
          const ranges = view.state.selection.ranges;
          const cursorOverlaps = ranges.some(({ from: from3, to: to3 }) => checkRangeOverlap([from3, to3], [parent.from, parent.to]));
          if (!cursorOverlaps) {
            widgets.push(...marks.map(({ from: from3, to: to3 }) => invisibleDecoration.range(from3, to3)), invisibleDecoration.range(from2, to2));
          }
          const dec = Decoration.widget({
            widget: new GoToLinkWidget(view.state.sliceDoc(from2, to2)),
            side: 1
          });
          widgets.push(dec.range(to2, to2));
        }
      }
    });
  }
  return Decoration.set(widgets, true);
}
const goToLinkPlugin = ViewPlugin.fromClass(class {
  constructor(view) {
    __publicField(this, "decorations", Decoration.none);
    this.decorations = getLinkAnchor(view);
  }
  update(update) {
    if (update.docChanged || update.viewportChanged || update.selectionSet)
      this.decorations = getLinkAnchor(update.view);
  }
}, { decorations: (v) => v.decorations });
const baseTheme = EditorView.baseTheme({
  ["." + classes.widget]: {
    cursor: "pointer",
    textDecoration: "underline"
  }
});
export {
  GoToLinkWidget,
  goToLinkPlugin,
  links
};
//# sourceMappingURL=link.js.map