import { syntaxTree } from "@codemirror/language";
import { StateField } from "@codemirror/state";
import { Slugger } from "../util";
const headingSlugField = StateField.define({
  create: (state) => {
    const slugs = new Array();
    extractSlugs(state);
    return slugs;
  },
  update: (value, tx) => {
    if (tx.docChanged)
      return extractSlugs(tx.state);
    return value;
  },
  compare: (a, b) => a.length === b.length && a.every((slug, i) => slug.slug === b[i].slug && slug.pos === b[i].pos)
});
function extractSlugs(state) {
  const slugs = [];
  const slugger = new Slugger();
  syntaxTree(state).iterate({
    enter: ({ name, from, to, node }) => {
      if (!name.includes("Heading"))
        return;
      const mark = node.getChild("HeaderMark");
      const headerText = state.sliceDoc(from, to).split("");
      headerText.splice(mark.from - from, mark.to - mark.from);
      const slug = slugger.slug(headerText.join("").trim());
      slugs.push({ slug, pos: from });
    }
  });
  return slugs;
}
export {
  headingSlugField
};
//# sourceMappingURL=heading-slug.js.map